@@ -67,18 +67,18 @@ def release_flow_main(
     """
     Construct a release id from git tag and commit history.
 
-    If HEAD commit is tagged then use the tag as the release id. Otherwise try to
-    count the number of commits since the most recent tag, with a PEP-440 constructed
-    release id of the form ``<tag>.post<N>``. Note that this implies that the tag
-    must be PEP-440 compliant.
+    If HEAD commit is tagged then use the tag as the release id. Otherwise try
+    to count the number of commits since the most recent tag, with a PEP-440
+    constructed release id of the form ``<tag>.post<N>``. Note that this
+    implies that the tag must be PEP-440 compliant.
 
     If there are no tags in commit history then a default tag of ``0.0.0`` is
     inferred and the number of commits counted since the root (first) commit in
     commit history.
 
-    The count method is slightly different when there are no tags in commit history
-    so it is recommended to tag the root commit with ``0.0.0`` so that the count
-    method is always the same.
+    The count method is slightly different when there are no tags in commit
+    history so it is recommended to tag the root commit with ``0.0.0`` so that
+    the count method is always the same.
     """
     try:
         logging_state = LoggingState(
