@@ -68,7 +68,9 @@ def _apply_formatting(venv_path: pathlib.Path) -> None:
     black_result = run_command(black_cmd)
     click.echo(click.style("black completed", fg="green"))
 
-    if any([x != 0 for x in [isort_result.returncode, black_result.returncode]]):
+    if any(
+        [x != 0 for x in [isort_result.returncode, black_result.returncode]]
+    ):
         raise FormattingError("isort and/or black failed during formatting.")
 
 
@@ -111,8 +113,8 @@ def formatting(ctx: click.Context, check: bool) -> None:
     """
     Run suite of Python code formatting.
 
-    The suite currently comprises "isort and "black". isort is run before black to
-    resolve cases where isort and black compete over formatting changes.
+    The suite currently comprises "isort and "black". isort is run before black
+    to resolve cases where isort and black compete over formatting changes.
     """
     try:
         command_state: CommandState = ctx.obj
