@@ -48,7 +48,8 @@ def _obfuscate_password(password: str) -> str:
         password: Password text to be obfuscated.
 
     Returns:
-        Last four characters of password, if possible. Completely obfuscated otherwise.
+        Last four characters of password, if possible. Completely obfuscated
+        otherwise.
     """
     obfuscated_password: str = (
         "**{0}".format(password[-4:]) if len(password) > 4 else "*****"
@@ -66,8 +67,8 @@ def _publish_packages(
     """
     Publish sdist, wheel packages using twine.
 
-    On dry run no publish occurs, but a summary of packages found that would have
-    been published is printed to console.
+    On dry run no publish occurs, but a summary of packages found that would
+    have been published is printed to console.
 
     Args:
         venv_path: Path to Python virtual environment.
@@ -85,26 +86,30 @@ def _publish_packages(
         this_command += ["--repository-url", PYPI_TEST_URL]
     this_command += ["dist/*.whl", "dist/*.tar.gz"]
 
-    environment_variables = dict()
+    environment_variables = {}
     if user:
         log.debug("twine username, {0}".format(user))
         environment_variables["TWINE_USERNAME"] = user
     else:
-        log.warning("twine username not provded. assuming twine can figure it out...")
+        log.warning(
+            "twine username not provded. assuming twine can figure it out..."
+        )
     if password:
         obfuscated_password = _obfuscate_password(password)
         log.debug("twine password, {0}".format(obfuscated_password))
         environment_variables["TWINE_PASSWORD"] = password
     else:
-        log.warning("twine password not provided. assuming twine can figure it out...")
+        log.warning(
+            "twine password not provided. assuming twine can figure it out..."
+        )
 
     if publish_option in [PublishOptions.yes, PublishOptions.test]:
         log.debug("twine command run, {0}".format(str(this_command)))
         result = run_command(
             this_command,
             env=environment_variables,
-            # suppress command logging in the run to protect accidental exposure of
-            # credentials
+            # suppress command logging in the run to protect accidental
+            # exposure of credentials
             suppress_command_logging=True,
             suppress_argument_logging=True,
         )
@@ -120,8 +125,8 @@ def _publish_packages(
         log.info(message)
         click.echo(message)
     else:
-        # it shouldn't be possible to get here, unless PublishOptions is changed in
-        # future in a way that the other conditionals don't cover.
+        # it shouldn't be possible to get here, unless PublishOptions is
+        # changed in future in a way that the other conditionals don't cover.
         raise PublishingError("Unknown publish option")
 
 
@@ -146,7 +151,8 @@ def _publish_packages(
 
     yes - publish to pypi.org.
     no - do not publish or dryrun.
-    dryrun - log the twine command to be run on publish without uploading anything.
+    dryrun - log the twine command to be run on publish without uploading
+             anything.
     test - publish to pypi.org test server.
 """,
     show_default=True,
@@ -172,7 +178,8 @@ def publish(
         this_password = None
         if password and password_file:
             raise PublishingError(
-                "Cannot specify both `--password` and `--password-file` options."
+                "Cannot specify both `--password` and `--password-file` "
+                "options."
             )
         elif password:
             log.debug(
@@ -183,7 +190,9 @@ def publish(
             this_password = password
         elif password_file:
             log.debug(
-                "password specified in password file, {0!r}".format(password_file.name)
+                "password specified in password file, {0!r}".format(
+                    password_file.name
+                )
             )
             this_password = typing.cast(str, password_file.read())
             if not this_password:
@@ -195,7 +204,10 @@ def publish(
             )
 
         _publish_packages(
-            command_state.venv_path, PublishOptions[publish], this_password, user
+            command_state.venv_path,
+            PublishOptions[publish],
+            this_password,
+            user,
         )
     except PublishingError as e:
         message = str(e)
