@@ -16,8 +16,12 @@ import typing
 
 import click
 
-from build_harness._project import acquire_source_dir
-from build_harness._utility import extract_coverage, report_console_error, run_command
+from build_harness._utility import (
+    extract_coverage,
+    report_console_error,
+    run_command,
+)
+from build_harness.project import acquire_source_dir
 from build_harness.tools import PytestCommand, TestCommandOptions
 
 from .state import CommandState, ExitState
@@ -79,8 +83,10 @@ def _run_tests(
         log.debug("coverage report, {0}".format(report_text))
         actual_coverage = extract_coverage(report_text)
         if actual_coverage < coverage_threshold:
-            message = "Coverage test failed, {0} (actual) < {1} (threshold)".format(
-                actual_coverage, coverage_threshold
+            message = (
+                "Coverage test failed, {0} (actual) < {1} (threshold)".format(
+                    actual_coverage, coverage_threshold
+                )
             )
             log.debug(message)
             raise TestCoverageError(message)
@@ -140,7 +146,9 @@ def _process_xml_coverage(
 
 
 def _process_junitxml(
-    junitxml: bool, junitxml_file: typing.Optional[str], output_path: pathlib.Path
+    junitxml: bool,
+    junitxml_file: typing.Optional[str],
+    output_path: pathlib.Path,
 ) -> typing.Tuple[bool, typing.Optional[pathlib.Path]]:
     junitxml_path: typing.Optional[pathlib.Path]
 
@@ -153,7 +161,9 @@ def _process_junitxml(
         junitxml_enabled = False
         junitxml_path = None
 
-    log.debug("JUnit XML test report enabled, {0}".format(str(junitxml_enabled)))
+    log.debug(
+        "JUnit XML test report enabled, {0}".format(str(junitxml_enabled))
+    )
     log.debug("JUnit XML test report path, {0}".format(str(junitxml_path)))
 
     return junitxml_enabled, junitxml_path
@@ -184,7 +194,8 @@ def _process_junitxml(
 @click.option(
     "{0}-file".format(COVERAGE_REPORT_ARGUMENTS[1]),
     default="",
-    help="Enable HTML coverage report. [default: auto directory location when enabled]",
+    help="Enable HTML coverage report. [default: auto directory location when "
+    "enabled]",
     metavar="DIRECTORY",
     type=str,
 )
@@ -198,7 +209,8 @@ def _process_junitxml(
 @click.option(
     "{0}-file".format(COVERAGE_REPORT_ARGUMENTS[2]),
     default="",
-    help="Enable XML coverage report. [default: auto file location, when enabled]",
+    help="Enable XML coverage report. [default: auto file location, when "
+    "enabled]",
     metavar="FILE",
     show_default=True,
     type=str,
@@ -222,8 +234,8 @@ def _process_junitxml(
 @click.option(
     "--output-dir",
     default=DEFAULT_OUTPUT_DIR,
-    help="Path to directory for placing output artifacts such as coverage report "
-    "files.",
+    help="Path to directory for placing output artifacts such as coverage "
+    "report files.",
     metavar="DIRECTORY",
     show_default=True,
     type=str,
@@ -268,8 +280,9 @@ def unit_test(
     """
     Run tests using the ``pytest`` unit test framework.
 
-    When enabled, any reports will be automatically placed in the output artifact
-    directory unless an alternative location is specified to the relevant argument.
+    When enabled, any reports will be automatically placed in the output
+    artifact directory unless an alternative location is specified to the
+    relevant argument.
     """
     try:
         command_state: CommandState = ctx.obj
