@@ -7,7 +7,7 @@
 #  If not, see <https://opensource.org/licenses/MIT>.
 #
 
-import features.steps.structure.bootstrap_steps
 import features.steps.structure.common_steps
+import features.steps.structure.dependencies_steps
 import features.steps.structure.package_steps
 import features.steps.structure.release_flow_steps
