@@ -101,7 +101,9 @@ class TestPublishPackages:
 
     def test_user(self, caplog, mock_run, mocker):
         with caplog.at_level(logging.DEBUG):
-            _publish_packages(self.MOCK_VENV, PublishOptions.yes, None, "this_user")
+            _publish_packages(
+                self.MOCK_VENV, PublishOptions.yes, None, "this_user"
+            )
 
             mock_run.assert_has_calls(
                 [
@@ -120,7 +122,9 @@ class TestPublishPackages:
 
     def test_password(self, caplog, mock_run, mocker):
         with caplog.at_level(logging.DEBUG):
-            _publish_packages(self.MOCK_VENV, PublishOptions.yes, "this_password", None)
+            _publish_packages(
+                self.MOCK_VENV, PublishOptions.yes, "this_password", None
+            )
 
             mock_run.assert_has_calls(
                 [
@@ -277,7 +281,9 @@ class TestPublish:
         mock_run.assert_not_called()
 
     def test_password_file(self, caplog, click_runner, mock_run, mocker):
-        with caplog.at_level(logging.DEBUG), tempfile.TemporaryDirectory() as dir:
+        with caplog.at_level(
+            logging.DEBUG
+        ), tempfile.TemporaryDirectory() as dir:
             this_dir = pathlib.Path(dir)
             this_file = this_dir / "this-file"
             with this_file.open(mode="w") as f:
